"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListEnvironments = void 0;
const ListEnvironmentsCommand_1 = require("../commands/ListEnvironmentsCommand");
const MigrationHubRefactorSpaces_1 = require("../MigrationHubRefactorSpaces");
const MigrationHubRefactorSpacesClient_1 = require("../MigrationHubRefactorSpacesClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListEnvironmentsCommand_1.ListEnvironmentsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listEnvironments(input, ...args);
};
async function* paginateListEnvironments(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof MigrationHubRefactorSpaces_1.MigrationHubRefactorSpaces) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof MigrationHubRefactorSpacesClient_1.MigrationHubRefactorSpacesClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected MigrationHubRefactorSpaces | MigrationHubRefactorSpacesClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListEnvironments = paginateListEnvironments;
