import { HttpHandlerOptions as __HttpHandlerOptions } from "@aws-sdk/types";
import { CreateApplicationCommandInput, CreateApplicationCommandOutput } from "./commands/CreateApplicationCommand";
import { CreateEnvironmentCommandInput, CreateEnvironmentCommandOutput } from "./commands/CreateEnvironmentCommand";
import { CreateRouteCommandInput, CreateRouteCommandOutput } from "./commands/CreateRouteCommand";
import { CreateServiceCommandInput, CreateServiceCommandOutput } from "./commands/CreateServiceCommand";
import { DeleteApplicationCommandInput, DeleteApplicationCommandOutput } from "./commands/DeleteApplicationCommand";
import { DeleteEnvironmentCommandInput, DeleteEnvironmentCommandOutput } from "./commands/DeleteEnvironmentCommand";
import { DeleteResourcePolicyCommandInput, DeleteResourcePolicyCommandOutput } from "./commands/DeleteResourcePolicyCommand";
import { DeleteRouteCommandInput, DeleteRouteCommandOutput } from "./commands/DeleteRouteCommand";
import { DeleteServiceCommandInput, DeleteServiceCommandOutput } from "./commands/DeleteServiceCommand";
import { GetApplicationCommandInput, GetApplicationCommandOutput } from "./commands/GetApplicationCommand";
import { GetEnvironmentCommandInput, GetEnvironmentCommandOutput } from "./commands/GetEnvironmentCommand";
import { GetResourcePolicyCommandInput, GetResourcePolicyCommandOutput } from "./commands/GetResourcePolicyCommand";
import { GetRouteCommandInput, GetRouteCommandOutput } from "./commands/GetRouteCommand";
import { GetServiceCommandInput, GetServiceCommandOutput } from "./commands/GetServiceCommand";
import { ListApplicationsCommandInput, ListApplicationsCommandOutput } from "./commands/ListApplicationsCommand";
import { ListEnvironmentsCommandInput, ListEnvironmentsCommandOutput } from "./commands/ListEnvironmentsCommand";
import { ListEnvironmentVpcsCommandInput, ListEnvironmentVpcsCommandOutput } from "./commands/ListEnvironmentVpcsCommand";
import { ListRoutesCommandInput, ListRoutesCommandOutput } from "./commands/ListRoutesCommand";
import { ListServicesCommandInput, ListServicesCommandOutput } from "./commands/ListServicesCommand";
import { ListTagsForResourceCommandInput, ListTagsForResourceCommandOutput } from "./commands/ListTagsForResourceCommand";
import { PutResourcePolicyCommandInput, PutResourcePolicyCommandOutput } from "./commands/PutResourcePolicyCommand";
import { TagResourceCommandInput, TagResourceCommandOutput } from "./commands/TagResourceCommand";
import { UntagResourceCommandInput, UntagResourceCommandOutput } from "./commands/UntagResourceCommand";
import { MigrationHubRefactorSpacesClient } from "./MigrationHubRefactorSpacesClient";
/**
 * <fullname>Amazon Web Services Migration Hub Refactor Spaces</fullname>
 *
 *          <p>This API reference provides descriptions, syntax, and other details about each of the
 *       actions and data types for Amazon Web Services Migration Hub Refactor Spaces (Refactor Spaces). The topic for each action shows the API
 *       request parameters and the response. Alternatively, you can use one of the Amazon Web Services SDKs to
 *       access an API that is tailored to the programming language or platform that you're using. For
 *       more information, see <a href="http://aws.amazon.com/tools/#SDKs">Amazon Web Services SDKs</a>.</p>
 *
 *          <p>To share Refactor Spaces environments with other Amazon Web Services accounts or with Organizations
 *         and their OUs, use Resource Access Manager's <code>CreateResourceShare</code> API. See <a href="https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html">CreateResourceShare</a> in the <i>Amazon Web Services RAM API Reference</i>.</p>
 */
export declare class MigrationHubRefactorSpaces extends MigrationHubRefactorSpacesClient {
    /**
     * <p>Creates an Amazon Web Services Migration Hub Refactor Spaces application. The account that owns the environment also owns the
     *       applications created inside the environment, regardless of the account that creates the
     *       application. Refactor Spaces provisions an Amazon API Gateway, API Gateway VPC link, and
     *         Network Load Balancer for the application proxy inside your account.</p>
     */
    createApplication(args: CreateApplicationCommandInput, options?: __HttpHandlerOptions): Promise<CreateApplicationCommandOutput>;
    createApplication(args: CreateApplicationCommandInput, cb: (err: any, data?: CreateApplicationCommandOutput) => void): void;
    createApplication(args: CreateApplicationCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateApplicationCommandOutput) => void): void;
    /**
     * <p>Creates an Amazon Web Services Migration Hub Refactor Spaces environment. The caller owns the environment resource, and all
     *       Refactor Spaces applications, services, and routes created within the environment. They are referred
     *       to as the <i>environment owner</i>. The environment owner has cross-account
     *       visibility and control of Refactor Spaces resources that are added to the environment by other
     *       accounts that the environment is shared with. When creating an environment, Refactor Spaces
     *       provisions a transit gateway in your account.</p>
     */
    createEnvironment(args: CreateEnvironmentCommandInput, options?: __HttpHandlerOptions): Promise<CreateEnvironmentCommandOutput>;
    createEnvironment(args: CreateEnvironmentCommandInput, cb: (err: any, data?: CreateEnvironmentCommandOutput) => void): void;
    createEnvironment(args: CreateEnvironmentCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateEnvironmentCommandOutput) => void): void;
    /**
     * <p>Creates an Amazon Web Services Migration Hub Refactor Spaces route. The account owner of the service resource is always the
     *       environment owner, regardless of which account creates the route. Routes target a service in
     *       the application. If an application does not have any routes, then the first route must be
     *       created as a <code>DEFAULT</code>
     *             <code>RouteType</code>.</p>
     *          <p>When you create a route, Refactor Spaces configures the Amazon API Gateway to send traffic
     *       to the target service as follows:</p>
     *          <ul>
     *             <li>
     *                <p>If the service has a URL endpoint, and the endpoint resolves to a private IP address,
     *           Refactor Spaces routes traffic using the API Gateway VPC link. </p>
     *             </li>
     *             <li>
     *                <p>If the service has a URL endpoint, and the endpoint resolves to a public IP address,
     *           Refactor Spaces routes traffic over the public internet.</p>
     *             </li>
     *             <li>
     *                <p>If the service has an Lambda function endpoint, then Refactor Spaces
     *           configures the Lambda function's resource policy to allow the application's
     *             API Gateway to invoke the function.</p>
     *             </li>
     *          </ul>
     *          <p>A one-time health check is performed on the service when the route is created. If the
     *       health check fails, the route transitions to <code>FAILED</code>, and no traffic is sent to
     *       the service.</p>
     *          <p>For Lambda functions, the Lambda function state is checked. If the
     *       function is not active, the function configuration is updated so that Lambda
     *       resources are provisioned. If the Lambda state is <code>Failed</code>, then the
     *       route creation fails. For more information, see the <a href="https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConfiguration.html#SSS-GetFunctionConfiguration-response-State">GetFunctionConfiguration's State response parameter</a> in the <i>Lambda Developer Guide</i>.</p>
     *          <p>For public URLs, a connection is opened to the public endpoint. If the URL is not
     *       reachable, the health check fails. For private URLs, a target group is created and the target
     *       group health check is run.</p>
     *          <p>The <code>HealthCheckProtocol</code>, <code>HealthCheckPort</code>, and
     *         <code>HealthCheckPath</code> are the same protocol, port, and path specified in the URL or
     *       health URL, if used. All other settings use the default values, as described in <a href="https://docs.aws.amazon.com/elasticloadbalancing/latest/application/target-group-health-checks.html">Health checks
     *         for your target groups</a>. The health check is considered successful if at least one
     *       target within the target group transitions to a healthy state.</p>
     *          <p>Services can have HTTP or HTTPS URL endpoints. For HTTPS URLs, publicly-signed
     *       certificates are supported. Private Certificate Authorities (CAs) are permitted only if the
     *       CA's domain is publicly resolvable.</p>
     */
    createRoute(args: CreateRouteCommandInput, options?: __HttpHandlerOptions): Promise<CreateRouteCommandOutput>;
    createRoute(args: CreateRouteCommandInput, cb: (err: any, data?: CreateRouteCommandOutput) => void): void;
    createRoute(args: CreateRouteCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateRouteCommandOutput) => void): void;
    /**
     * <p>Creates an Amazon Web Services Migration Hub Refactor Spaces service. The account owner of the service is always the
     *       environment owner, regardless of which account in the environment creates the service.
     *       Services have either a URL endpoint in a virtual private cloud (VPC), or a Lambda
     *       function endpoint.</p>
     *          <important>
     *             <p>If an Amazon Web Services resource is launched in a service VPC, and you want it to be
     *         accessible to all of an environment’s services with VPCs and routes, apply the
     *           <code>RefactorSpacesSecurityGroup</code> to the resource. Alternatively, to add more
     *         cross-account constraints, apply your own security group.</p>
     *          </important>
     */
    createService(args: CreateServiceCommandInput, options?: __HttpHandlerOptions): Promise<CreateServiceCommandOutput>;
    createService(args: CreateServiceCommandInput, cb: (err: any, data?: CreateServiceCommandOutput) => void): void;
    createService(args: CreateServiceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: CreateServiceCommandOutput) => void): void;
    /**
     * <p>Deletes an Amazon Web Services Migration Hub Refactor Spaces application. Before you can delete an application, you must first
     *       delete any services or routes within the application.</p>
     */
    deleteApplication(args: DeleteApplicationCommandInput, options?: __HttpHandlerOptions): Promise<DeleteApplicationCommandOutput>;
    deleteApplication(args: DeleteApplicationCommandInput, cb: (err: any, data?: DeleteApplicationCommandOutput) => void): void;
    deleteApplication(args: DeleteApplicationCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteApplicationCommandOutput) => void): void;
    /**
     * <p>Deletes an Amazon Web Services Migration Hub Refactor Spaces environment. Before you can delete an environment, you must first
     *       delete any applications and services within the environment.</p>
     */
    deleteEnvironment(args: DeleteEnvironmentCommandInput, options?: __HttpHandlerOptions): Promise<DeleteEnvironmentCommandOutput>;
    deleteEnvironment(args: DeleteEnvironmentCommandInput, cb: (err: any, data?: DeleteEnvironmentCommandOutput) => void): void;
    deleteEnvironment(args: DeleteEnvironmentCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteEnvironmentCommandOutput) => void): void;
    /**
     * <p>Deletes the resource policy set for the environment. </p>
     */
    deleteResourcePolicy(args: DeleteResourcePolicyCommandInput, options?: __HttpHandlerOptions): Promise<DeleteResourcePolicyCommandOutput>;
    deleteResourcePolicy(args: DeleteResourcePolicyCommandInput, cb: (err: any, data?: DeleteResourcePolicyCommandOutput) => void): void;
    deleteResourcePolicy(args: DeleteResourcePolicyCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteResourcePolicyCommandOutput) => void): void;
    /**
     * <p>Deletes an Amazon Web Services Migration Hub Refactor Spaces route.</p>
     */
    deleteRoute(args: DeleteRouteCommandInput, options?: __HttpHandlerOptions): Promise<DeleteRouteCommandOutput>;
    deleteRoute(args: DeleteRouteCommandInput, cb: (err: any, data?: DeleteRouteCommandOutput) => void): void;
    deleteRoute(args: DeleteRouteCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteRouteCommandOutput) => void): void;
    /**
     * <p>Deletes an Amazon Web Services Migration Hub Refactor Spaces service. </p>
     */
    deleteService(args: DeleteServiceCommandInput, options?: __HttpHandlerOptions): Promise<DeleteServiceCommandOutput>;
    deleteService(args: DeleteServiceCommandInput, cb: (err: any, data?: DeleteServiceCommandOutput) => void): void;
    deleteService(args: DeleteServiceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: DeleteServiceCommandOutput) => void): void;
    /**
     * <p>Gets an Amazon Web Services Migration Hub Refactor Spaces application.</p>
     */
    getApplication(args: GetApplicationCommandInput, options?: __HttpHandlerOptions): Promise<GetApplicationCommandOutput>;
    getApplication(args: GetApplicationCommandInput, cb: (err: any, data?: GetApplicationCommandOutput) => void): void;
    getApplication(args: GetApplicationCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: GetApplicationCommandOutput) => void): void;
    /**
     * <p>Gets an Amazon Web Services Migration Hub Refactor Spaces environment.</p>
     */
    getEnvironment(args: GetEnvironmentCommandInput, options?: __HttpHandlerOptions): Promise<GetEnvironmentCommandOutput>;
    getEnvironment(args: GetEnvironmentCommandInput, cb: (err: any, data?: GetEnvironmentCommandOutput) => void): void;
    getEnvironment(args: GetEnvironmentCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: GetEnvironmentCommandOutput) => void): void;
    /**
     * <p>Gets the resource-based permission policy that is set for the given environment. </p>
     */
    getResourcePolicy(args: GetResourcePolicyCommandInput, options?: __HttpHandlerOptions): Promise<GetResourcePolicyCommandOutput>;
    getResourcePolicy(args: GetResourcePolicyCommandInput, cb: (err: any, data?: GetResourcePolicyCommandOutput) => void): void;
    getResourcePolicy(args: GetResourcePolicyCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: GetResourcePolicyCommandOutput) => void): void;
    /**
     * <p>Gets an Amazon Web Services Migration Hub Refactor Spaces route.</p>
     */
    getRoute(args: GetRouteCommandInput, options?: __HttpHandlerOptions): Promise<GetRouteCommandOutput>;
    getRoute(args: GetRouteCommandInput, cb: (err: any, data?: GetRouteCommandOutput) => void): void;
    getRoute(args: GetRouteCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: GetRouteCommandOutput) => void): void;
    /**
     * <p>Gets an Amazon Web Services Migration Hub Refactor Spaces service. </p>
     */
    getService(args: GetServiceCommandInput, options?: __HttpHandlerOptions): Promise<GetServiceCommandOutput>;
    getService(args: GetServiceCommandInput, cb: (err: any, data?: GetServiceCommandOutput) => void): void;
    getService(args: GetServiceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: GetServiceCommandOutput) => void): void;
    /**
     * <p>Lists all the Amazon Web Services Migration Hub Refactor Spaces applications within an environment. </p>
     */
    listApplications(args: ListApplicationsCommandInput, options?: __HttpHandlerOptions): Promise<ListApplicationsCommandOutput>;
    listApplications(args: ListApplicationsCommandInput, cb: (err: any, data?: ListApplicationsCommandOutput) => void): void;
    listApplications(args: ListApplicationsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListApplicationsCommandOutput) => void): void;
    /**
     * <p>Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a caller account or shared with the caller
     *       account. </p>
     */
    listEnvironments(args: ListEnvironmentsCommandInput, options?: __HttpHandlerOptions): Promise<ListEnvironmentsCommandOutput>;
    listEnvironments(args: ListEnvironmentsCommandInput, cb: (err: any, data?: ListEnvironmentsCommandOutput) => void): void;
    listEnvironments(args: ListEnvironmentsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListEnvironmentsCommandOutput) => void): void;
    /**
     * <p>Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual private clouds (VPCs) that are part of the
     *       environment. </p>
     */
    listEnvironmentVpcs(args: ListEnvironmentVpcsCommandInput, options?: __HttpHandlerOptions): Promise<ListEnvironmentVpcsCommandOutput>;
    listEnvironmentVpcs(args: ListEnvironmentVpcsCommandInput, cb: (err: any, data?: ListEnvironmentVpcsCommandOutput) => void): void;
    listEnvironmentVpcs(args: ListEnvironmentVpcsCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListEnvironmentVpcsCommandOutput) => void): void;
    /**
     * <p>Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application. </p>
     */
    listRoutes(args: ListRoutesCommandInput, options?: __HttpHandlerOptions): Promise<ListRoutesCommandOutput>;
    listRoutes(args: ListRoutesCommandInput, cb: (err: any, data?: ListRoutesCommandOutput) => void): void;
    listRoutes(args: ListRoutesCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListRoutesCommandOutput) => void): void;
    /**
     * <p>Lists all the Amazon Web Services Migration Hub Refactor Spaces services within an application. </p>
     */
    listServices(args: ListServicesCommandInput, options?: __HttpHandlerOptions): Promise<ListServicesCommandOutput>;
    listServices(args: ListServicesCommandInput, cb: (err: any, data?: ListServicesCommandOutput) => void): void;
    listServices(args: ListServicesCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListServicesCommandOutput) => void): void;
    /**
     * <p>Lists the tags of a resource. The caller account must be the same as the resource’s
     *         <code>OwnerAccountId</code>. Listing tags in other accounts is not supported. </p>
     */
    listTagsForResource(args: ListTagsForResourceCommandInput, options?: __HttpHandlerOptions): Promise<ListTagsForResourceCommandOutput>;
    listTagsForResource(args: ListTagsForResourceCommandInput, cb: (err: any, data?: ListTagsForResourceCommandOutput) => void): void;
    listTagsForResource(args: ListTagsForResourceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: ListTagsForResourceCommandOutput) => void): void;
    /**
     * <p>Attaches a resource-based permission policy to the Amazon Web Services Migration Hub Refactor Spaces environment. The policy
     *       must contain the same actions and condition statements as the
     *         <code>arn:aws:ram::aws:permission/AWSRAMDefaultPermissionRefactorSpacesEnvironment</code>
     *       permission in Resource Access Manager. The policy must not contain new lines or blank lines.
     *     </p>
     */
    putResourcePolicy(args: PutResourcePolicyCommandInput, options?: __HttpHandlerOptions): Promise<PutResourcePolicyCommandOutput>;
    putResourcePolicy(args: PutResourcePolicyCommandInput, cb: (err: any, data?: PutResourcePolicyCommandOutput) => void): void;
    putResourcePolicy(args: PutResourcePolicyCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: PutResourcePolicyCommandOutput) => void): void;
    /**
     * <p>Removes the tags of a given resource. Tags are metadata which can be used to manage a
     *       resource. To tag a resource, the caller account must be the same as the resource’s
     *         <code>OwnerAccountId</code>. Tagging resources in other accounts is not supported.</p>
     *          <note>
     *             <p>Amazon Web Services Migration Hub Refactor Spaces does not propagate tags to orchestrated resources, such as an
     *         environment’s transit gateway.</p>
     *          </note>
     */
    tagResource(args: TagResourceCommandInput, options?: __HttpHandlerOptions): Promise<TagResourceCommandOutput>;
    tagResource(args: TagResourceCommandInput, cb: (err: any, data?: TagResourceCommandOutput) => void): void;
    tagResource(args: TagResourceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: TagResourceCommandOutput) => void): void;
    /**
     * <p>Adds to or modifies the tags of the given resource. Tags are metadata which can be used to
     *       manage a resource. To untag a resource, the caller account must be the same as the resource’s
     *         <code>OwnerAccountId</code>. Untagging resources across accounts is not supported. </p>
     */
    untagResource(args: UntagResourceCommandInput, options?: __HttpHandlerOptions): Promise<UntagResourceCommandOutput>;
    untagResource(args: UntagResourceCommandInput, cb: (err: any, data?: UntagResourceCommandOutput) => void): void;
    untagResource(args: UntagResourceCommandInput, options: __HttpHandlerOptions, cb: (err: any, data?: UntagResourceCommandOutput) => void): void;
}
