import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MigrationHubRefactorSpacesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MigrationHubRefactorSpacesClient";
import { CreateEnvironmentRequest, CreateEnvironmentResponse } from "../models/models_0";
export interface CreateEnvironmentCommandInput extends CreateEnvironmentRequest {
}
export interface CreateEnvironmentCommandOutput extends CreateEnvironmentResponse, __MetadataBearer {
}
/**
 * <p>Creates an Amazon Web Services Migration Hub Refactor Spaces environment. The caller owns the environment resource, and all
 *       Refactor Spaces applications, services, and routes created within the environment. They are referred
 *       to as the <i>environment owner</i>. The environment owner has cross-account
 *       visibility and control of Refactor Spaces resources that are added to the environment by other
 *       accounts that the environment is shared with. When creating an environment, Refactor Spaces
 *       provisions a transit gateway in your account.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MigrationHubRefactorSpacesClient, CreateEnvironmentCommand } from "@aws-sdk/client-migration-hub-refactor-spaces"; // ES Modules import
 * // const { MigrationHubRefactorSpacesClient, CreateEnvironmentCommand } = require("@aws-sdk/client-migration-hub-refactor-spaces"); // CommonJS import
 * const client = new MigrationHubRefactorSpacesClient(config);
 * const command = new CreateEnvironmentCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateEnvironmentCommandInput} for command's `input` shape.
 * @see {@link CreateEnvironmentCommandOutput} for command's `response` shape.
 * @see {@link MigrationHubRefactorSpacesClientResolvedConfig | config} for MigrationHubRefactorSpacesClient's `config` shape.
 *
 */
export declare class CreateEnvironmentCommand extends $Command<CreateEnvironmentCommandInput, CreateEnvironmentCommandOutput, MigrationHubRefactorSpacesClientResolvedConfig> {
    readonly input: CreateEnvironmentCommandInput;
    constructor(input: CreateEnvironmentCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MigrationHubRefactorSpacesClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateEnvironmentCommandInput, CreateEnvironmentCommandOutput>;
    private serialize;
    private deserialize;
}
