import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MigrationHubRefactorSpacesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MigrationHubRefactorSpacesClient";
import { CreateServiceRequest, CreateServiceResponse } from "../models/models_0";
export interface CreateServiceCommandInput extends CreateServiceRequest {
}
export interface CreateServiceCommandOutput extends CreateServiceResponse, __MetadataBearer {
}
/**
 * <p>Creates an Amazon Web Services Migration Hub Refactor Spaces service. The account owner of the service is always the
 *       environment owner, regardless of which account in the environment creates the service.
 *       Services have either a URL endpoint in a virtual private cloud (VPC), or a Lambda
 *       function endpoint.</p>
 *          <important>
 *             <p>If an Amazon Web Services resource is launched in a service VPC, and you want it to be
 *         accessible to all of an environment’s services with VPCs and routes, apply the
 *           <code>RefactorSpacesSecurityGroup</code> to the resource. Alternatively, to add more
 *         cross-account constraints, apply your own security group.</p>
 *          </important>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MigrationHubRefactorSpacesClient, CreateServiceCommand } from "@aws-sdk/client-migration-hub-refactor-spaces"; // ES Modules import
 * // const { MigrationHubRefactorSpacesClient, CreateServiceCommand } = require("@aws-sdk/client-migration-hub-refactor-spaces"); // CommonJS import
 * const client = new MigrationHubRefactorSpacesClient(config);
 * const command = new CreateServiceCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateServiceCommandInput} for command's `input` shape.
 * @see {@link CreateServiceCommandOutput} for command's `response` shape.
 * @see {@link MigrationHubRefactorSpacesClientResolvedConfig | config} for MigrationHubRefactorSpacesClient's `config` shape.
 *
 */
export declare class CreateServiceCommand extends $Command<CreateServiceCommandInput, CreateServiceCommandOutput, MigrationHubRefactorSpacesClientResolvedConfig> {
    readonly input: CreateServiceCommandInput;
    constructor(input: CreateServiceCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MigrationHubRefactorSpacesClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateServiceCommandInput, CreateServiceCommandOutput>;
    private serialize;
    private deserialize;
}
