import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { MigrationHubRefactorSpacesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../MigrationHubRefactorSpacesClient";
import { ListRoutesRequest, ListRoutesResponse } from "../models/models_0";
export interface ListRoutesCommandInput extends ListRoutesRequest {
}
export interface ListRoutesCommandOutput extends ListRoutesResponse, __MetadataBearer {
}
/**
 * <p>Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { MigrationHubRefactorSpacesClient, ListRoutesCommand } from "@aws-sdk/client-migration-hub-refactor-spaces"; // ES Modules import
 * // const { MigrationHubRefactorSpacesClient, ListRoutesCommand } = require("@aws-sdk/client-migration-hub-refactor-spaces"); // CommonJS import
 * const client = new MigrationHubRefactorSpacesClient(config);
 * const command = new ListRoutesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListRoutesCommandInput} for command's `input` shape.
 * @see {@link ListRoutesCommandOutput} for command's `response` shape.
 * @see {@link MigrationHubRefactorSpacesClientResolvedConfig | config} for MigrationHubRefactorSpacesClient's `config` shape.
 *
 */
export declare class ListRoutesCommand extends $Command<ListRoutesCommandInput, ListRoutesCommandOutput, MigrationHubRefactorSpacesClientResolvedConfig> {
    readonly input: ListRoutesCommandInput;
    constructor(input: ListRoutesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: MigrationHubRefactorSpacesClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListRoutesCommandInput, ListRoutesCommandOutput>;
    private serialize;
    private deserialize;
}
