import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { MigrationHubRefactorSpacesServiceException as __BaseException } from "./MigrationHubRefactorSpacesServiceException";
/**
 * <p>The user does not have sufficient access to perform this action. </p>
 */
export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
export declare enum ApiGatewayEndpointType {
    PRIVATE = "PRIVATE",
    REGIONAL = "REGIONAL"
}
/**
 * <p>A wrapper object holding the Amazon API Gateway proxy configuration. </p>
 */
export interface ApiGatewayProxyConfig {
    /**
     * <p>The endpoint URL of the API Gateway proxy. </p>
     */
    ProxyUrl?: string;
    /**
     * <p>The resource ID of the API Gateway for the proxy. </p>
     */
    ApiGatewayId?: string;
    /**
     * <p>The <code>VpcLink</code> ID of the API Gateway proxy. </p>
     */
    VpcLinkId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the Network Load Balancer configured by the API Gateway proxy. </p>
     */
    NlbArn?: string;
    /**
     * <p>The name of the Network Load Balancer that is configured by the API Gateway proxy.
     *     </p>
     */
    NlbName?: string;
    /**
     * <p>The type of API Gateway endpoint created. </p>
     */
    EndpointType?: ApiGatewayEndpointType | string;
    /**
     * <p>The name of the API Gateway stage. The name defaults to <code>prod</code>. </p>
     */
    StageName?: string;
}
export declare namespace ApiGatewayProxyConfig {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ApiGatewayProxyConfig) => any;
}
/**
 * <p>A wrapper object holding the Amazon API Gateway endpoint input. </p>
 */
export interface ApiGatewayProxyInput {
    /**
     * <p>The type of endpoint to use for the API Gateway proxy. If no value is specified in
     *       the request, the value is set to <code>REGIONAL</code> by default.</p>
     *          <p>If the value is set to <code>PRIVATE</code> in the request, this creates a private API
     *       endpoint that is isolated from the public internet. The private endpoint can only be accessed
     *       by using Amazon Virtual Private Cloud (Amazon VPC) endpoints for Amazon API Gateway that
     *       have been granted access. </p>
     */
    EndpointType?: ApiGatewayEndpointType | string;
    /**
     * <p>The name of the API Gateway stage. The name defaults to <code>prod</code>. </p>
     */
    StageName?: string;
}
export declare namespace ApiGatewayProxyInput {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ApiGatewayProxyInput) => any;
}
/**
 * <p>A wrapper object holding the Amazon API Gateway proxy summary. </p>
 */
export interface ApiGatewayProxySummary {
    /**
     * <p>The endpoint URL of the API Gateway proxy. </p>
     */
    ProxyUrl?: string;
    /**
     * <p>The resource ID of the API Gateway for the proxy. </p>
     */
    ApiGatewayId?: string;
    /**
     * <p>The <code>VpcLink</code> ID of the API Gateway proxy. </p>
     */
    VpcLinkId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the Network Load Balancer configured by the API Gateway proxy. </p>
     */
    NlbArn?: string;
    /**
     * <p>The name of the Network Load Balancer that is configured by the API Gateway proxy.
     *     </p>
     */
    NlbName?: string;
    /**
     * <p>The type of API Gateway endpoint created. </p>
     */
    EndpointType?: ApiGatewayEndpointType | string;
    /**
     * <p>The name of the API Gateway stage. The name defaults to <code>prod</code>. </p>
     */
    StageName?: string;
}
export declare namespace ApiGatewayProxySummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ApiGatewayProxySummary) => any;
}
export declare enum ApplicationState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED",
    UPDATING = "UPDATING"
}
export declare enum ErrorCode {
    INVALID_RESOURCE_STATE = "INVALID_RESOURCE_STATE",
    NOT_AUTHORIZED = "NOT_AUTHORIZED",
    REQUEST_LIMIT_EXCEEDED = "REQUEST_LIMIT_EXCEEDED",
    RESOURCE_CREATION_FAILURE = "RESOURCE_CREATION_FAILURE",
    RESOURCE_DELETION_FAILURE = "RESOURCE_DELETION_FAILURE",
    RESOURCE_IN_USE = "RESOURCE_IN_USE",
    RESOURCE_LIMIT_EXCEEDED = "RESOURCE_LIMIT_EXCEEDED",
    RESOURCE_NOT_FOUND = "RESOURCE_NOT_FOUND",
    RESOURCE_RETRIEVAL_FAILURE = "RESOURCE_RETRIEVAL_FAILURE",
    RESOURCE_UPDATE_FAILURE = "RESOURCE_UPDATE_FAILURE",
    SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE = "SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE",
    STATE_TRANSITION_FAILURE = "STATE_TRANSITION_FAILURE"
}
export declare enum ErrorResourceType {
    API_GATEWAY = "API_GATEWAY",
    APPLICATION = "APPLICATION",
    ENVIRONMENT = "ENVIRONMENT",
    IAM_ROLE = "IAM_ROLE",
    LAMBDA = "LAMBDA",
    LOAD_BALANCER_LISTENER = "LOAD_BALANCER_LISTENER",
    NLB = "NLB",
    RESOURCE_SHARE = "RESOURCE_SHARE",
    ROUTE = "ROUTE",
    ROUTE_TABLE = "ROUTE_TABLE",
    SECURITY_GROUP = "SECURITY_GROUP",
    SERVICE = "SERVICE",
    SUBNET = "SUBNET",
    TARGET_GROUP = "TARGET_GROUP",
    TRANSIT_GATEWAY = "TRANSIT_GATEWAY",
    TRANSIT_GATEWAY_ATTACHMENT = "TRANSIT_GATEWAY_ATTACHMENT",
    VPC = "VPC",
    VPC_ENDPOINT_SERVICE_CONFIGURATION = "VPC_ENDPOINT_SERVICE_CONFIGURATION",
    VPC_LINK = "VPC_LINK"
}
/**
 * <p>Error associated with a resource returned for a Get or List resource response. </p>
 */
export interface ErrorResponse {
    /**
     * <p>The error code associated with the error. </p>
     */
    Code?: ErrorCode | string;
    /**
     * <p>The message associated with the error. </p>
     */
    Message?: string;
    /**
     * <p>The Amazon Web Services account ID of the resource owner. </p>
     */
    AccountId?: string;
    /**
     * <p>The ID of the resource. </p>
     */
    ResourceIdentifier?: string;
    /**
     * <p>The type of resource. </p>
     */
    ResourceType?: ErrorResourceType | string;
    /**
     * <p>Additional details about the error. </p>
     */
    AdditionalDetails?: {
        [key: string]: string;
    };
}
export declare namespace ErrorResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ErrorResponse) => any;
}
export declare enum ProxyType {
    API_GATEWAY = "API_GATEWAY"
}
/**
 * <p>The list of <code>ApplicationSummary</code> objects. </p>
 */
export interface ApplicationSummary {
    /**
     * <p>The name of the application. </p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the application. </p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the application owner (which is always the same as
     *       the environment owner account ID).</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the application creator. </p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The unique identifier of the application. </p>
     */
    ApplicationId?: string;
    /**
     * <p>The unique identifier of the environment. </p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the virtual private cloud (VPC). </p>
     */
    VpcId?: string;
    /**
     * <p>The proxy type of the proxy created within the application. </p>
     */
    ProxyType?: ProxyType | string;
    /**
     * <p>The endpoint URL of the Amazon API Gateway proxy. </p>
     */
    ApiGatewayProxy?: ApiGatewayProxySummary;
    /**
     * <p>The current state of the application. </p>
     */
    State?: ApplicationState | string;
    /**
     * <p>The tags assigned to the application. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the application resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the application was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the application is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace ApplicationSummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ApplicationSummary) => any;
}
/**
 * <p>Updating or deleting a resource can cause an inconsistent state.</p>
 */
export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * <p>The ID of the resource. </p>
     */
    ResourceId: string | undefined;
    /**
     * <p>The type of resource. </p>
     */
    ResourceType: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface CreateApplicationRequest {
    /**
     * <p>The name to use for the application. </p>
     */
    Name: string | undefined;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the virtual private cloud (VPC).</p>
     */
    VpcId: string | undefined;
    /**
     * <p>The proxy type of the proxy created within the application. </p>
     */
    ProxyType: ProxyType | string | undefined;
    /**
     * <p>A wrapper object holding the API Gateway endpoint type and stage name for the
     *       proxy. </p>
     */
    ApiGatewayProxy?: ApiGatewayProxyInput;
    /**
     * <p>The tags to assign to the application. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair.</p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A unique, case-sensitive identifier that you provide to ensure the idempotency of the
     *       request.</p>
     */
    ClientToken?: string;
}
export declare namespace CreateApplicationRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateApplicationRequest) => any;
}
export interface CreateApplicationResponse {
    /**
     * <p>The name of the application.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the application. The format for this ARN is
     * <code>arn:aws:refactor-spaces:<i>region</i>:<i>account-id</i>:<i>resource-type/resource-id</i>
     *             </code>. For more information about ARNs,
     * see <a href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">
     *                     Amazon Resource Names (ARNs)</a> in the
     *                     <i>Amazon Web Services General Reference</i>.</p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the application owner (which is always the same as
     *       the environment owner account ID).</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of application creator.</p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The unique identifier of the application.</p>
     */
    ApplicationId?: string;
    /**
     * <p>The ID of the environment in which the application is created.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the Amazon VPC. </p>
     */
    VpcId?: string;
    /**
     * <p>The proxy type of the proxy created within the application. </p>
     */
    ProxyType?: ProxyType | string;
    /**
     * <p>A wrapper object holding the API Gateway endpoint type and stage name for the
     *       proxy. </p>
     */
    ApiGatewayProxy?: ApiGatewayProxyInput;
    /**
     * <p>The current state of the application. </p>
     */
    State?: ApplicationState | string;
    /**
     * <p>The tags assigned to the application. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A timestamp that indicates when the application was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the application is created.</p>
     */
    CreatedTime?: Date;
}
export declare namespace CreateApplicationResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateApplicationResponse) => any;
}
/**
 * <p>An unexpected error occurred while processing the request.</p>
 */
export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}
/**
 * <p>The request references a resource that does not exist. </p>
 */
export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * <p>The ID of the resource. </p>
     */
    ResourceId: string | undefined;
    /**
     * <p>The type of resource. </p>
     */
    ResourceType: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}
/**
 * <p>The request would cause a service quota to be exceeded. </p>
 */
export declare class ServiceQuotaExceededException extends __BaseException {
    readonly name: "ServiceQuotaExceededException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * <p>The ID of the resource. </p>
     */
    ResourceId: string | undefined;
    /**
     * <p>The type of resource. </p>
     */
    ResourceType: string | undefined;
    /**
     * <p>Service quota requirement to identify originating quota. Reached throttling quota
     *       exception. </p>
     */
    QuotaCode?: string;
    /**
     * <p>Service quota requirement to identify originating service. Reached throttling quota
     *       exception service code. </p>
     */
    ServiceCode: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>);
}
/**
 * <p>Request was denied because the request was throttled. </p>
 */
export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * <p>Service quota requirement to identify originating quota. Reached throttling quota
     *       exception. </p>
     */
    QuotaCode?: string;
    /**
     * <p>Service quota requirement to identify originating service. Reached throttling quota
     *       exception service code. </p>
     */
    ServiceCode?: string;
    /**
     * <p>The number of seconds to wait before retrying. </p>
     */
    RetryAfterSeconds?: number;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}
/**
 * <p>The input does not satisfy the constraints specified by an Amazon Web Service.
 *     </p>
 */
export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
export declare enum NetworkFabricType {
    TRANSIT_GATEWAY = "TRANSIT_GATEWAY"
}
export interface CreateEnvironmentRequest {
    /**
     * <p>The name of the environment.</p>
     */
    Name: string | undefined;
    /**
     * <p>The description of the environment.</p>
     */
    Description?: string;
    /**
     * <p>The network fabric type of the environment.</p>
     */
    NetworkFabricType: NetworkFabricType | string | undefined;
    /**
     * <p>The tags to assign to the environment. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair.</p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A unique, case-sensitive identifier that you provide to ensure the idempotency of the
     *       request.</p>
     */
    ClientToken?: string;
}
export declare namespace CreateEnvironmentRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateEnvironmentRequest) => any;
}
export declare enum EnvironmentState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED"
}
export interface CreateEnvironmentResponse {
    /**
     * <p>The name of the environment.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the environment.</p>
     */
    Arn?: string;
    /**
     * <p>A description of the environment.</p>
     */
    Description?: string;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The network fabric type of the environment.</p>
     */
    NetworkFabricType?: NetworkFabricType | string;
    /**
     * <p>The Amazon Web Services account ID of environment owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The current state of the environment. </p>
     */
    State?: EnvironmentState | string;
    /**
     * <p>The tags assigned to the created environment. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair..</p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A timestamp that indicates when the environment was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the environment is created.</p>
     */
    CreatedTime?: Date;
}
export declare namespace CreateEnvironmentResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateEnvironmentResponse) => any;
}
export declare enum RouteType {
    DEFAULT = "DEFAULT",
    URI_PATH = "URI_PATH"
}
export declare enum RouteActivationState {
    ACTIVE = "ACTIVE"
}
export declare enum HttpMethod {
    DELETE = "DELETE",
    GET = "GET",
    HEAD = "HEAD",
    OPTIONS = "OPTIONS",
    PATCH = "PATCH",
    POST = "POST",
    PUT = "PUT"
}
/**
 * <p>The configuration for the URI path route type. </p>
 */
export interface UriPathRouteInput {
    /**
     * <p>The path to use to match traffic. Paths must start with <code>/</code> and are relative to
     *       the base of the application.</p>
     */
    SourcePath: string | undefined;
    /**
     * <p>Indicates whether traffic is forwarded to this route’s service after the route is created.
     *     </p>
     */
    ActivationState: RouteActivationState | string | undefined;
    /**
     * <p>A list of HTTP methods to match. An empty list matches all values. If a method is present,
     *       only HTTP requests using that method are forwarded to this route’s service. </p>
     */
    Methods?: (HttpMethod | string)[];
    /**
     * <p>Indicates whether to match all subpaths of the given source path. If this value is
     *         <code>false</code>, requests must match the source path exactly before they are forwarded to
     *       this route's service. </p>
     */
    IncludeChildPaths?: boolean;
}
export declare namespace UriPathRouteInput {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UriPathRouteInput) => any;
}
export interface CreateRouteRequest {
    /**
     * <p>The ID of the environment in which the route is created.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application within which the route is being created.</p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The ID of the service in which the route is created. Traffic that matches this route is
     *       forwarded to this service.</p>
     */
    ServiceIdentifier: string | undefined;
    /**
     * <p>The route type of the route. <code>DEFAULT</code> indicates that all traffic that does not
     *       match another route is forwarded to the default route. Applications must have a default route
     *       before any other routes can be created. <code>URI_PATH</code> indicates a route that is based
     *       on a URI path.</p>
     */
    RouteType: RouteType | string | undefined;
    /**
     * <p>The configuration for the URI path route type. </p>
     */
    UriPathRoute?: UriPathRouteInput;
    /**
     * <p>The tags to assign to the route. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair.. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A unique, case-sensitive identifier that you provide to ensure the idempotency of the
     *       request.</p>
     */
    ClientToken?: string;
}
export declare namespace CreateRouteRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateRouteRequest) => any;
}
export declare enum RouteState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED",
    INACTIVE = "INACTIVE",
    UPDATING = "UPDATING"
}
export interface CreateRouteResponse {
    /**
     * <p>The unique identifier of the route.</p>
     */
    RouteId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the route. The format for this ARN is
     * <code>arn:aws:refactor-spaces:<i>region</i>:<i>account-id</i>:<i>resource-type/resource-id</i>
     *             </code>. For more information about ARNs,
     * see <a href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">
     *                     Amazon Resource Names (ARNs)</a> in the
     *                     <i>Amazon Web Services General Reference</i>.</p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the route owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the route creator.</p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The route type of the route.</p>
     */
    RouteType?: RouteType | string;
    /**
     * <p>The ID of service in which the route is created. Traffic that matches this route is
     *       forwarded to this service.</p>
     */
    ServiceId?: string;
    /**
     * <p>The ID of the application in which the route is created.</p>
     */
    ApplicationId?: string;
    /**
     * <p>onfiguration for the URI path route type. </p>
     */
    UriPathRoute?: UriPathRouteInput;
    /**
     * <p>The current state of the route. </p>
     */
    State?: RouteState | string;
    /**
     * <p>The tags assigned to the created route. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A timestamp that indicates when the route was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the route is created.</p>
     */
    CreatedTime?: Date;
}
export declare namespace CreateRouteResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateRouteResponse) => any;
}
export declare enum ServiceEndpointType {
    LAMBDA = "LAMBDA",
    URL = "URL"
}
/**
 * <p>The input for the Lambda endpoint type. </p>
 */
export interface LambdaEndpointInput {
    /**
     * <p>The Amazon Resource Name (ARN) of the Lambda endpoint. </p>
     */
    Arn: string | undefined;
}
export declare namespace LambdaEndpointInput {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: LambdaEndpointInput) => any;
}
/**
 * <p>The configuration for the URL endpoint type. </p>
 */
export interface UrlEndpointInput {
    /**
     * <p>The URL to route traffic to. The URL must be an <a href="https://datatracker.ietf.org/doc/html/rfc3986">rfc3986-formatted URL</a>. If the
     *       host is a domain name, the name must be resolvable over the public internet. If the scheme is
     *         <code>https</code>, the top level domain of the host must be listed in the <a href="https://www.iana.org/domains/root/db">IANA root zone database</a>. </p>
     */
    Url: string | undefined;
    /**
     * <p>The health check URL of the URL endpoint type. If the URL is a public endpoint, the
     *         <code>HealthUrl</code> must also be a public endpoint. If the URL is a private endpoint
     *       inside a virtual private cloud (VPC), the health URL must also be a private endpoint, and the
     *       host must be the same as the URL. </p>
     */
    HealthUrl?: string;
}
export declare namespace UrlEndpointInput {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UrlEndpointInput) => any;
}
export interface CreateServiceRequest {
    /**
     * <p>The name of the service.</p>
     */
    Name: string | undefined;
    /**
     * <p>The description of the service.</p>
     */
    Description?: string;
    /**
     * <p>The ID of the environment in which the service is created.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application which the service is created.</p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The ID of the VPC.</p>
     */
    VpcId?: string;
    /**
     * <p>The type of endpoint to use for the service. The type can be a URL in a VPC or an Lambda function.</p>
     */
    EndpointType: ServiceEndpointType | string | undefined;
    /**
     * <p>The configuration for the URL endpoint type.</p>
     */
    UrlEndpoint?: UrlEndpointInput;
    /**
     * <p>The configuration for the Lambda endpoint type.</p>
     */
    LambdaEndpoint?: LambdaEndpointInput;
    /**
     * <p>The tags to assign to the service. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair.. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A unique, case-sensitive identifier that you provide to ensure the idempotency of the
     *       request.</p>
     */
    ClientToken?: string;
}
export declare namespace CreateServiceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateServiceRequest) => any;
}
export declare enum ServiceState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED"
}
export interface CreateServiceResponse {
    /**
     * <p>The unique identifier of the service.</p>
     */
    ServiceId?: string;
    /**
     * <p>The name of the service.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the service.</p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the service owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the service creator.</p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The description of the created service.</p>
     */
    Description?: string;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the application that the created service belongs to. </p>
     */
    ApplicationId?: string;
    /**
     * <p>The ID of the VPC. </p>
     */
    VpcId?: string;
    /**
     * <p>The endpoint type of the service.</p>
     */
    EndpointType?: ServiceEndpointType | string;
    /**
     * <p>The configuration for the URL endpoint type. </p>
     */
    UrlEndpoint?: UrlEndpointInput;
    /**
     * <p>The configuration for the Lambda endpoint type.</p>
     */
    LambdaEndpoint?: LambdaEndpointInput;
    /**
     * <p>The current state of the service. </p>
     */
    State?: ServiceState | string;
    /**
     * <p>The tags assigned to the created service. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair.. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>A timestamp that indicates when the service was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the service is created.</p>
     */
    CreatedTime?: Date;
}
export declare namespace CreateServiceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: CreateServiceResponse) => any;
}
export interface DeleteApplicationRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application.</p>
     */
    ApplicationIdentifier: string | undefined;
}
export declare namespace DeleteApplicationRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteApplicationRequest) => any;
}
export interface DeleteApplicationResponse {
    /**
     * <p>The name of the application.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the application.</p>
     */
    Arn?: string;
    /**
     * <p>The ID of the application.</p>
     */
    ApplicationId?: string;
    /**
     * <p>The unique identifier of the application’s environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The current state of the application. </p>
     */
    State?: ApplicationState | string;
    /**
     * <p>A timestamp that indicates when the environment was last updated. </p>
     */
    LastUpdatedTime?: Date;
}
export declare namespace DeleteApplicationResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteApplicationResponse) => any;
}
export interface DeleteEnvironmentRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
}
export declare namespace DeleteEnvironmentRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteEnvironmentRequest) => any;
}
export interface DeleteEnvironmentResponse {
    /**
     * <p>The name of the environment.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the environment.</p>
     */
    Arn?: string;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The current state of the environment. </p>
     */
    State?: EnvironmentState | string;
    /**
     * <p>A timestamp that indicates when the environment was last updated. </p>
     */
    LastUpdatedTime?: Date;
}
export declare namespace DeleteEnvironmentResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteEnvironmentResponse) => any;
}
export interface DeleteResourcePolicyRequest {
    /**
     * <p>Amazon Resource Name (ARN) of the resource associated with the policy. </p>
     */
    Identifier: string | undefined;
}
export declare namespace DeleteResourcePolicyRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteResourcePolicyRequest) => any;
}
export interface DeleteResourcePolicyResponse {
}
export declare namespace DeleteResourcePolicyResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteResourcePolicyResponse) => any;
}
export interface DeleteRouteRequest {
    /**
     * <p>The ID of the environment to delete the route from.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application to delete the route from.</p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The ID of the route to delete.</p>
     */
    RouteIdentifier: string | undefined;
}
export declare namespace DeleteRouteRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteRouteRequest) => any;
}
export interface DeleteRouteResponse {
    /**
     * <p>The ID of the route to delete.</p>
     */
    RouteId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the route.</p>
     */
    Arn?: string;
    /**
     * <p>The ID of the service that the route belongs to.</p>
     */
    ServiceId?: string;
    /**
     * <p>The ID of the application that the route belongs to.</p>
     */
    ApplicationId?: string;
    /**
     * <p>The current state of the route. </p>
     */
    State?: RouteState | string;
    /**
     * <p>A timestamp that indicates when the route was last updated. </p>
     */
    LastUpdatedTime?: Date;
}
export declare namespace DeleteRouteResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteRouteResponse) => any;
}
export interface DeleteServiceRequest {
    /**
     * <p>The ID of the environment that the service is in.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>Deletes a Refactor Spaces service.</p>
     *          <note>
     *             <p>The <code>RefactorSpacesSecurityGroup</code> security group must be removed from all
     *         Amazon Web Services resources in the virtual private cloud (VPC) prior to deleting a service with a URL
     *         endpoint in a VPC.</p>
     *          </note>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The ID of the service to delete.</p>
     */
    ServiceIdentifier: string | undefined;
}
export declare namespace DeleteServiceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteServiceRequest) => any;
}
export interface DeleteServiceResponse {
    /**
     * <p>The unique identifier of the service.</p>
     */
    ServiceId?: string;
    /**
     * <p>The name of the service.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the service.</p>
     */
    Arn?: string;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the application that the service is in.</p>
     */
    ApplicationId?: string;
    /**
     * <p>The current state of the service. </p>
     */
    State?: ServiceState | string;
    /**
     * <p>A timestamp that indicates when the service was last updated. </p>
     */
    LastUpdatedTime?: Date;
}
export declare namespace DeleteServiceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: DeleteServiceResponse) => any;
}
/**
 * <p>The summary information for environments as a response to <code>ListEnvironments</code>.
 *     </p>
 */
export interface EnvironmentSummary {
    /**
     * <p>The name of the environment. </p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the environment. </p>
     */
    Arn?: string;
    /**
     * <p>A description of the environment. </p>
     */
    Description?: string;
    /**
     * <p>The unique identifier of the environment. </p>
     */
    EnvironmentId?: string;
    /**
     * <p>The network fabric type of the environment. </p>
     */
    NetworkFabricType?: NetworkFabricType | string;
    /**
     * <p>The Amazon Web Services account ID of the environment owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The ID of the transit gateway set up by the environment. </p>
     */
    TransitGatewayId?: string;
    /**
     * <p>The current state of the environment. </p>
     */
    State?: EnvironmentState | string;
    /**
     * <p>The tags assigned to the environment. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the environment resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the environment was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the environment is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace EnvironmentSummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: EnvironmentSummary) => any;
}
/**
 * <p>Provides summary information for the <code>EnvironmentVpc</code> resource as a response to
 *         <code>ListEnvironmentVpc</code>.</p>
 */
export interface EnvironmentVpc {
    /**
     * <p>The unique identifier of the environment. </p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the VPC. </p>
     */
    VpcId?: string;
    /**
     * <p>The Amazon Web Services account ID of the virtual private cloud (VPC) owner. </p>
     */
    AccountId?: string;
    /**
     * <p>The list of Amazon Virtual Private Cloud (Amazon VPC) CIDR blocks. </p>
     */
    CidrBlocks?: string[];
    /**
     * <p>The name of the VPC at the time it is added to the environment. </p>
     */
    VpcName?: string;
    /**
     * <p>A timestamp that indicates when the VPC was last updated by the environment. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the VPC is first added to the environment. </p>
     */
    CreatedTime?: Date;
}
export declare namespace EnvironmentVpc {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: EnvironmentVpc) => any;
}
export interface GetApplicationRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application.</p>
     */
    ApplicationIdentifier: string | undefined;
}
export declare namespace GetApplicationRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetApplicationRequest) => any;
}
export interface GetApplicationResponse {
    /**
     * <p>The name of the application.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the application.</p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the application owner (which is always the same as
     *       the environment owner account ID).</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the application creator. </p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The unique identifier of the application.</p>
     */
    ApplicationId?: string;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the virtual private cloud (VPC). </p>
     */
    VpcId?: string;
    /**
     * <p>The proxy type of the proxy created within the application. </p>
     */
    ProxyType?: ProxyType | string;
    /**
     * <p>The endpoint URL of the API Gateway proxy. </p>
     */
    ApiGatewayProxy?: ApiGatewayProxyConfig;
    /**
     * <p>The current state of the application. </p>
     */
    State?: ApplicationState | string;
    /**
     * <p>The tags assigned to the application. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the application resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the application was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the application is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace GetApplicationResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetApplicationResponse) => any;
}
export interface GetEnvironmentRequest {
    /**
     * <p>The ID of the environment.</p>
     */
    EnvironmentIdentifier: string | undefined;
}
export declare namespace GetEnvironmentRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetEnvironmentRequest) => any;
}
export interface GetEnvironmentResponse {
    /**
     * <p>The name of the environment.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the environment.</p>
     */
    Arn?: string;
    /**
     * <p>The description of the environment. </p>
     */
    Description?: string;
    /**
     * <p>The unique identifier of the environment. </p>
     */
    EnvironmentId?: string;
    /**
     * <p>The network fabric type of the environment. </p>
     */
    NetworkFabricType?: NetworkFabricType | string;
    /**
     * <p>The Amazon Web Services account ID of the environment owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The ID of the transit gateway set up by the environment. </p>
     */
    TransitGatewayId?: string;
    /**
     * <p>The current state of the environment. </p>
     */
    State?: EnvironmentState | string;
    /**
     * <p>The tags to assign to the environment. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the environment resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the environment was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the environment is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace GetEnvironmentResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetEnvironmentResponse) => any;
}
export interface GetResourcePolicyRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource associated with the policy. </p>
     */
    Identifier: string | undefined;
}
export declare namespace GetResourcePolicyRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetResourcePolicyRequest) => any;
}
export interface GetResourcePolicyResponse {
    /**
     * <p>A JSON-formatted string for an Amazon Web Services resource-based policy. </p>
     */
    Policy?: string;
}
export declare namespace GetResourcePolicyResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetResourcePolicyResponse) => any;
}
export interface GetRouteRequest {
    /**
     * <p>The ID of the environment.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application. </p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The ID of the route.</p>
     */
    RouteIdentifier: string | undefined;
}
export declare namespace GetRouteRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetRouteRequest) => any;
}
export interface GetRouteResponse {
    /**
     * <p>The unique identifier of the route.</p>
     *          <p>
     *             <b>DEFAULT</b>: All traffic that does not match another route is
     *       forwarded to the default route. Applications must have a default route before any other routes
     *       can be created.</p>
     *          <p>
     *             <b>URI_PATH</b>: A route that is based on a URI path.</p>
     */
    RouteId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the route.</p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the route owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the route creator.</p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The type of route.</p>
     */
    RouteType?: RouteType | string;
    /**
     * <p>The unique identifier of the service.</p>
     */
    ServiceId?: string;
    /**
     * <p>The ID of the application that the route belongs to. </p>
     */
    ApplicationId?: string;
    /**
     * <p>Unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The path to use to match traffic. Paths must start with <code>/</code> and are relative to
     *       the base of the application. </p>
     */
    SourcePath?: string;
    /**
     * <p>A list of HTTP methods to match. An empty list matches all values. If a method is present,
     *       only HTTP requests using that method are forwarded to this route’s service. </p>
     */
    Methods?: (HttpMethod | string)[];
    /**
     * <p>Indicates whether to match all subpaths of the given source path. If this value is
     *         <code>false</code>, requests must match the source path exactly before they are forwarded to
     *       this route's service. </p>
     */
    IncludeChildPaths?: boolean;
    /**
     * <p>A mapping of Amazon API Gateway path resources to resource IDs. </p>
     */
    PathResourceToId?: {
        [key: string]: string;
    };
    /**
     * <p>The current state of the route. </p>
     */
    State?: RouteState | string;
    /**
     * <p>The tags assigned to the route. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the route resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the route was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>The timestamp of when the route is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace GetRouteResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetRouteResponse) => any;
}
export interface GetServiceRequest {
    /**
     * <p>The ID of the environment.</p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application.</p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The ID of the service.</p>
     */
    ServiceIdentifier: string | undefined;
}
export declare namespace GetServiceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetServiceRequest) => any;
}
/**
 * <p>The configuration for the Lambda endpoint type. </p>
 */
export interface LambdaEndpointConfig {
    /**
     * <p>The Amazon Resource Name (ARN) of the Lambda endpoint. </p>
     */
    Arn?: string;
}
export declare namespace LambdaEndpointConfig {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: LambdaEndpointConfig) => any;
}
/**
 * <p>The configuration for the URL endpoint type. </p>
 */
export interface UrlEndpointConfig {
    /**
     * <p>The HTTP URL endpoint. </p>
     */
    Url?: string;
    /**
     * <p>The health check URL of the URL endpoint type. </p>
     */
    HealthUrl?: string;
}
export declare namespace UrlEndpointConfig {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UrlEndpointConfig) => any;
}
export interface GetServiceResponse {
    /**
     * <p>The unique identifier of the service.</p>
     */
    ServiceId?: string;
    /**
     * <p>The name of the service.</p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the service.</p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the service owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the service creator.</p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The description of the service. </p>
     */
    Description?: string;
    /**
     * <p>The unique identifier of the environment.</p>
     */
    EnvironmentId?: string;
    /**
     * <p>The ID of the application.</p>
     */
    ApplicationId?: string;
    /**
     * <p>The ID of the virtual private cloud (VPC). </p>
     */
    VpcId?: string;
    /**
     * <p>The endpoint type of the service.</p>
     */
    EndpointType?: ServiceEndpointType | string;
    /**
     * <p>The configuration for the URL endpoint type.</p>
     *          <p>The <b>Url</b> isthe URL of the endpoint type.</p>
     *          <p>The <b>HealthUrl</b> is the health check URL of the endpoint
     *       type. </p>
     */
    UrlEndpoint?: UrlEndpointConfig;
    /**
     * <p>The configuration for the Lambda endpoint type.</p>
     *          <p>The <b>Arn</b> is the Amazon Resource Name (ARN) of the Lambda function associated with this service. </p>
     */
    LambdaEndpoint?: LambdaEndpointConfig;
    /**
     * <p>The current state of the service. </p>
     */
    State?: ServiceState | string;
    /**
     * <p>The tags assigned to the service. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key-value pair. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the service resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the service was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>The timestamp of when the service is created.</p>
     */
    CreatedTime?: Date;
}
export declare namespace GetServiceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: GetServiceResponse) => any;
}
/**
 * <p>The resource policy is not valid.</p>
 */
export declare class InvalidResourcePolicyException extends __BaseException {
    readonly name: "InvalidResourcePolicyException";
    readonly $fault: "client";
    Message: string | undefined;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidResourcePolicyException, __BaseException>);
}
/**
 * <p>The summary for the Lambda endpoint type. </p>
 */
export interface LambdaEndpointSummary {
    /**
     * <p>The Amazon Resource Name (ARN) of the Lambda endpoint. </p>
     */
    Arn?: string;
}
export declare namespace LambdaEndpointSummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: LambdaEndpointSummary) => any;
}
export interface ListApplicationsRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return with a single call. To retrieve the remaining
     *       results, make another call with the returned <code>nextToken</code> value.</p>
     */
    MaxResults?: number;
}
export declare namespace ListApplicationsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListApplicationsRequest) => any;
}
export interface ListApplicationsResponse {
    /**
     * <p>The list of <code>ApplicationSummary</code> objects. </p>
     */
    ApplicationSummaryList?: ApplicationSummary[];
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
}
export declare namespace ListApplicationsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListApplicationsResponse) => any;
}
export interface ListEnvironmentsRequest {
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return with a single call. To retrieve the remaining
     *       results, make another call with the returned <code>nextToken</code> value.</p>
     */
    MaxResults?: number;
}
export declare namespace ListEnvironmentsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListEnvironmentsRequest) => any;
}
export interface ListEnvironmentsResponse {
    /**
     * <p>The list of <code>EnvironmentSummary</code> objects. </p>
     */
    EnvironmentSummaryList?: EnvironmentSummary[];
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
}
export declare namespace ListEnvironmentsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListEnvironmentsResponse) => any;
}
export interface ListEnvironmentVpcsRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return with a single call. To retrieve the remaining
     *       results, make another call with the returned <code>nextToken</code> value.</p>
     */
    MaxResults?: number;
}
export declare namespace ListEnvironmentVpcsRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListEnvironmentVpcsRequest) => any;
}
export interface ListEnvironmentVpcsResponse {
    /**
     * <p>The list of <code>EnvironmentVpc</code> objects. </p>
     */
    EnvironmentVpcList?: EnvironmentVpc[];
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
}
export declare namespace ListEnvironmentVpcsResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListEnvironmentVpcsResponse) => any;
}
export interface ListRoutesRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application. </p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return with a single call. To retrieve the remaining
     *       results, make another call with the returned <code>nextToken</code> value.</p>
     */
    MaxResults?: number;
}
export declare namespace ListRoutesRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListRoutesRequest) => any;
}
/**
 * <p>The summary information for the routes as a response to <code>ListRoutes</code>. </p>
 */
export interface RouteSummary {
    /**
     * <p>The unique identifier of the route. </p>
     */
    RouteId?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the route. </p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the route owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the route creator. </p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>The route type of the route. </p>
     */
    RouteType?: RouteType | string;
    /**
     * <p>The unique identifier of the service. </p>
     */
    ServiceId?: string;
    /**
     * <p>The unique identifier of the application. </p>
     */
    ApplicationId?: string;
    /**
     * <p>The unique identifier of the environment. </p>
     */
    EnvironmentId?: string;
    /**
     * <p>The path to use to match traffic. Paths must start with <code>/</code> and are relative to
     *       the base of the application.</p>
     */
    SourcePath?: string;
    /**
     * <p>A list of HTTP methods to match. An empty list matches all values. If a method is present,
     *       only HTTP requests using that method are forwarded to this route’s service. </p>
     */
    Methods?: (HttpMethod | string)[];
    /**
     * <p>Indicates whether to match all subpaths of the given source path. If this value is
     *         <code>false</code>, requests must match the source path exactly before they are forwarded to
     *       this route's service.</p>
     */
    IncludeChildPaths?: boolean;
    /**
     * <p>A mapping of Amazon API Gateway path resources to resource IDs. </p>
     */
    PathResourceToId?: {
        [key: string]: string;
    };
    /**
     * <p>The current state of the route. </p>
     */
    State?: RouteState | string;
    /**
     * <p>The tags assigned to the route. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the route resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the route was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the route is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace RouteSummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: RouteSummary) => any;
}
export interface ListRoutesResponse {
    /**
     * <p>The list of <code>RouteSummary</code> objects. </p>
     */
    RouteSummaryList?: RouteSummary[];
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
}
export declare namespace ListRoutesResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListRoutesResponse) => any;
}
export interface ListServicesRequest {
    /**
     * <p>The ID of the environment. </p>
     */
    EnvironmentIdentifier: string | undefined;
    /**
     * <p>The ID of the application. </p>
     */
    ApplicationIdentifier: string | undefined;
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return with a single call. To retrieve the remaining
     *       results, make another call with the returned <code>nextToken</code> value.</p>
     */
    MaxResults?: number;
}
export declare namespace ListServicesRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListServicesRequest) => any;
}
/**
 * <p>The summary of the configuration for the URL endpoint type. </p>
 */
export interface UrlEndpointSummary {
    /**
     * <p> The URL to route traffic to. The URL must be an <a href="https://datatracker.ietf.org/doc/html/rfc3986">rfc3986-formatted URL</a>. If the
     *       host is a domain name, the name must be resolvable over the public internet. If the scheme is
     *         <code>https</code>, the top level domain of the host must be listed in the <a href="https://www.iana.org/domains/root/db">IANA root zone database</a>. </p>
     */
    Url?: string;
    /**
     * <p>The health check URL of the URL endpoint type. If the URL is a public endpoint, the
     *         <code>HealthUrl</code> must also be a public endpoint. If the URL is a private endpoint
     *       inside a virtual private cloud (VPC), the health URL must also be a private endpoint, and the
     *       host must be the same as the URL.</p>
     */
    HealthUrl?: string;
}
export declare namespace UrlEndpointSummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UrlEndpointSummary) => any;
}
/**
 * <p>A summary for the service as a response to <code>ListServices</code>. </p>
 */
export interface ServiceSummary {
    /**
     * <p>The unique identifier of the service. </p>
     */
    ServiceId?: string;
    /**
     * <p>The name of the service. </p>
     */
    Name?: string;
    /**
     * <p>The Amazon Resource Name (ARN) of the service. </p>
     */
    Arn?: string;
    /**
     * <p>The Amazon Web Services account ID of the service owner.</p>
     */
    OwnerAccountId?: string;
    /**
     * <p>The Amazon Web Services account ID of the service creator. </p>
     */
    CreatedByAccountId?: string;
    /**
     * <p>A description of the service. </p>
     */
    Description?: string;
    /**
     * <p>The unique identifier of the environment. </p>
     */
    EnvironmentId?: string;
    /**
     * <p>The unique identifier of the application. </p>
     */
    ApplicationId?: string;
    /**
     * <p>The ID of the virtual private cloud (VPC). </p>
     */
    VpcId?: string;
    /**
     * <p>The endpoint type of the service. </p>
     */
    EndpointType?: ServiceEndpointType | string;
    /**
     * <p>The summary of the configuration for the URL endpoint type. </p>
     */
    UrlEndpoint?: UrlEndpointSummary;
    /**
     * <p>A summary of the configuration for the Lambda endpoint type. </p>
     */
    LambdaEndpoint?: LambdaEndpointSummary;
    /**
     * <p>The current state of the service. </p>
     */
    State?: ServiceState | string;
    /**
     * <p>The tags assigned to the service. </p>
     */
    Tags?: {
        [key: string]: string;
    };
    /**
     * <p>Any error associated with the service resource. </p>
     */
    Error?: ErrorResponse;
    /**
     * <p>A timestamp that indicates when the service was last updated. </p>
     */
    LastUpdatedTime?: Date;
    /**
     * <p>A timestamp that indicates when the service is created. </p>
     */
    CreatedTime?: Date;
}
export declare namespace ServiceSummary {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ServiceSummary) => any;
}
export interface ListServicesResponse {
    /**
     * <p> The list of <code>ServiceSummary</code> objects. </p>
     */
    ServiceSummaryList?: ServiceSummary[];
    /**
     * <p>The token for the next page of results.</p>
     */
    NextToken?: string;
}
export declare namespace ListServicesResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListServicesResponse) => any;
}
export interface ListTagsForResourceRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource. </p>
     */
    ResourceArn: string | undefined;
}
export declare namespace ListTagsForResourceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
}
export interface ListTagsForResourceResponse {
    /**
     * <p>The list of tags assigned to the resource. </p>
     */
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace ListTagsForResourceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: ListTagsForResourceResponse) => any;
}
export interface PutResourcePolicyRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource to which the policy is being attached.
     *     </p>
     */
    ResourceArn: string | undefined;
    /**
     * <p>A JSON-formatted string for an Amazon Web Services resource-based policy. </p>
     */
    Policy: string | undefined;
}
export declare namespace PutResourcePolicyRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: PutResourcePolicyRequest) => any;
}
export interface PutResourcePolicyResponse {
}
export declare namespace PutResourcePolicyResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: PutResourcePolicyResponse) => any;
}
export interface TagResourceRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource</p>
     */
    ResourceArn: string | undefined;
    /**
     * <p>The new or modified tags for the resource. </p>
     */
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagResourceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResponse {
}
export declare namespace TagResourceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: TagResourceResponse) => any;
}
export interface UntagResourceRequest {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource. </p>
     */
    ResourceArn: string | undefined;
    /**
     * <p>The list of keys of the tags to be removed from the resource. </p>
     */
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResponse {
}
export declare namespace UntagResourceResponse {
    /**
     * @internal
     */
    const filterSensitiveLog: (obj: UntagResourceResponse) => any;
}
