import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { MigrationHubRefactorSpacesServiceException as __BaseException } from "./MigrationHubRefactorSpacesServiceException";

export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
export declare enum ApiGatewayEndpointType {
    PRIVATE = "PRIVATE",
    REGIONAL = "REGIONAL"
}

export interface ApiGatewayProxyConfig {
    
    ProxyUrl?: string;
    
    ApiGatewayId?: string;
    
    VpcLinkId?: string;
    
    NlbArn?: string;
    
    NlbName?: string;
    
    EndpointType?: ApiGatewayEndpointType | string;
    
    StageName?: string;
}
export declare namespace ApiGatewayProxyConfig {
    
    const filterSensitiveLog: (obj: ApiGatewayProxyConfig) => any;
}

export interface ApiGatewayProxyInput {
    
    EndpointType?: ApiGatewayEndpointType | string;
    
    StageName?: string;
}
export declare namespace ApiGatewayProxyInput {
    
    const filterSensitiveLog: (obj: ApiGatewayProxyInput) => any;
}

export interface ApiGatewayProxySummary {
    
    ProxyUrl?: string;
    
    ApiGatewayId?: string;
    
    VpcLinkId?: string;
    
    NlbArn?: string;
    
    NlbName?: string;
    
    EndpointType?: ApiGatewayEndpointType | string;
    
    StageName?: string;
}
export declare namespace ApiGatewayProxySummary {
    
    const filterSensitiveLog: (obj: ApiGatewayProxySummary) => any;
}
export declare enum ApplicationState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED",
    UPDATING = "UPDATING"
}
export declare enum ErrorCode {
    INVALID_RESOURCE_STATE = "INVALID_RESOURCE_STATE",
    NOT_AUTHORIZED = "NOT_AUTHORIZED",
    REQUEST_LIMIT_EXCEEDED = "REQUEST_LIMIT_EXCEEDED",
    RESOURCE_CREATION_FAILURE = "RESOURCE_CREATION_FAILURE",
    RESOURCE_DELETION_FAILURE = "RESOURCE_DELETION_FAILURE",
    RESOURCE_IN_USE = "RESOURCE_IN_USE",
    RESOURCE_LIMIT_EXCEEDED = "RESOURCE_LIMIT_EXCEEDED",
    RESOURCE_NOT_FOUND = "RESOURCE_NOT_FOUND",
    RESOURCE_RETRIEVAL_FAILURE = "RESOURCE_RETRIEVAL_FAILURE",
    RESOURCE_UPDATE_FAILURE = "RESOURCE_UPDATE_FAILURE",
    SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE = "SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE",
    STATE_TRANSITION_FAILURE = "STATE_TRANSITION_FAILURE"
}
export declare enum ErrorResourceType {
    API_GATEWAY = "API_GATEWAY",
    APPLICATION = "APPLICATION",
    ENVIRONMENT = "ENVIRONMENT",
    IAM_ROLE = "IAM_ROLE",
    LAMBDA = "LAMBDA",
    LOAD_BALANCER_LISTENER = "LOAD_BALANCER_LISTENER",
    NLB = "NLB",
    RESOURCE_SHARE = "RESOURCE_SHARE",
    ROUTE = "ROUTE",
    ROUTE_TABLE = "ROUTE_TABLE",
    SECURITY_GROUP = "SECURITY_GROUP",
    SERVICE = "SERVICE",
    SUBNET = "SUBNET",
    TARGET_GROUP = "TARGET_GROUP",
    TRANSIT_GATEWAY = "TRANSIT_GATEWAY",
    TRANSIT_GATEWAY_ATTACHMENT = "TRANSIT_GATEWAY_ATTACHMENT",
    VPC = "VPC",
    VPC_ENDPOINT_SERVICE_CONFIGURATION = "VPC_ENDPOINT_SERVICE_CONFIGURATION",
    VPC_LINK = "VPC_LINK"
}

export interface ErrorResponse {
    
    Code?: ErrorCode | string;
    
    Message?: string;
    
    AccountId?: string;
    
    ResourceIdentifier?: string;
    
    ResourceType?: ErrorResourceType | string;
    
    AdditionalDetails?: {
        [key: string]: string;
    };
}
export declare namespace ErrorResponse {
    
    const filterSensitiveLog: (obj: ErrorResponse) => any;
}
export declare enum ProxyType {
    API_GATEWAY = "API_GATEWAY"
}

export interface ApplicationSummary {
    
    Name?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    ApplicationId?: string;
    
    EnvironmentId?: string;
    
    VpcId?: string;
    
    ProxyType?: ProxyType | string;
    
    ApiGatewayProxy?: ApiGatewayProxySummary;
    
    State?: ApplicationState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace ApplicationSummary {
    
    const filterSensitiveLog: (obj: ApplicationSummary) => any;
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message: string | undefined;
    
    ResourceId: string | undefined;
    
    ResourceType: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface CreateApplicationRequest {
    
    Name: string | undefined;
    
    EnvironmentIdentifier: string | undefined;
    
    VpcId: string | undefined;
    
    ProxyType: ProxyType | string | undefined;
    
    ApiGatewayProxy?: ApiGatewayProxyInput;
    
    Tags?: {
        [key: string]: string;
    };
    
    ClientToken?: string;
}
export declare namespace CreateApplicationRequest {
    
    const filterSensitiveLog: (obj: CreateApplicationRequest) => any;
}
export interface CreateApplicationResponse {
    
    Name?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    ApplicationId?: string;
    
    EnvironmentId?: string;
    
    VpcId?: string;
    
    ProxyType?: ProxyType | string;
    
    ApiGatewayProxy?: ApiGatewayProxyInput;
    
    State?: ApplicationState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace CreateApplicationResponse {
    
    const filterSensitiveLog: (obj: CreateApplicationResponse) => any;
}

export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message: string | undefined;
    
    ResourceId: string | undefined;
    
    ResourceType: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}

export declare class ServiceQuotaExceededException extends __BaseException {
    readonly name: "ServiceQuotaExceededException";
    readonly $fault: "client";
    Message: string | undefined;
    
    ResourceId: string | undefined;
    
    ResourceType: string | undefined;
    
    QuotaCode?: string;
    
    ServiceCode: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>);
}

export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    Message: string | undefined;
    
    QuotaCode?: string;
    
    ServiceCode?: string;
    
    RetryAfterSeconds?: number;
    
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
export declare enum NetworkFabricType {
    TRANSIT_GATEWAY = "TRANSIT_GATEWAY"
}
export interface CreateEnvironmentRequest {
    
    Name: string | undefined;
    
    Description?: string;
    
    NetworkFabricType: NetworkFabricType | string | undefined;
    
    Tags?: {
        [key: string]: string;
    };
    
    ClientToken?: string;
}
export declare namespace CreateEnvironmentRequest {
    
    const filterSensitiveLog: (obj: CreateEnvironmentRequest) => any;
}
export declare enum EnvironmentState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED"
}
export interface CreateEnvironmentResponse {
    
    Name?: string;
    
    Arn?: string;
    
    Description?: string;
    
    EnvironmentId?: string;
    
    NetworkFabricType?: NetworkFabricType | string;
    
    OwnerAccountId?: string;
    
    State?: EnvironmentState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace CreateEnvironmentResponse {
    
    const filterSensitiveLog: (obj: CreateEnvironmentResponse) => any;
}
export declare enum RouteType {
    DEFAULT = "DEFAULT",
    URI_PATH = "URI_PATH"
}
export declare enum RouteActivationState {
    ACTIVE = "ACTIVE"
}
export declare enum HttpMethod {
    DELETE = "DELETE",
    GET = "GET",
    HEAD = "HEAD",
    OPTIONS = "OPTIONS",
    PATCH = "PATCH",
    POST = "POST",
    PUT = "PUT"
}

export interface UriPathRouteInput {
    
    SourcePath: string | undefined;
    
    ActivationState: RouteActivationState | string | undefined;
    
    Methods?: (HttpMethod | string)[];
    
    IncludeChildPaths?: boolean;
}
export declare namespace UriPathRouteInput {
    
    const filterSensitiveLog: (obj: UriPathRouteInput) => any;
}
export interface CreateRouteRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    ServiceIdentifier: string | undefined;
    
    RouteType: RouteType | string | undefined;
    
    UriPathRoute?: UriPathRouteInput;
    
    Tags?: {
        [key: string]: string;
    };
    
    ClientToken?: string;
}
export declare namespace CreateRouteRequest {
    
    const filterSensitiveLog: (obj: CreateRouteRequest) => any;
}
export declare enum RouteState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED",
    INACTIVE = "INACTIVE",
    UPDATING = "UPDATING"
}
export interface CreateRouteResponse {
    
    RouteId?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    RouteType?: RouteType | string;
    
    ServiceId?: string;
    
    ApplicationId?: string;
    
    UriPathRoute?: UriPathRouteInput;
    
    State?: RouteState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace CreateRouteResponse {
    
    const filterSensitiveLog: (obj: CreateRouteResponse) => any;
}
export declare enum ServiceEndpointType {
    LAMBDA = "LAMBDA",
    URL = "URL"
}

export interface LambdaEndpointInput {
    
    Arn: string | undefined;
}
export declare namespace LambdaEndpointInput {
    
    const filterSensitiveLog: (obj: LambdaEndpointInput) => any;
}

export interface UrlEndpointInput {
    
    Url: string | undefined;
    
    HealthUrl?: string;
}
export declare namespace UrlEndpointInput {
    
    const filterSensitiveLog: (obj: UrlEndpointInput) => any;
}
export interface CreateServiceRequest {
    
    Name: string | undefined;
    
    Description?: string;
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    VpcId?: string;
    
    EndpointType: ServiceEndpointType | string | undefined;
    
    UrlEndpoint?: UrlEndpointInput;
    
    LambdaEndpoint?: LambdaEndpointInput;
    
    Tags?: {
        [key: string]: string;
    };
    
    ClientToken?: string;
}
export declare namespace CreateServiceRequest {
    
    const filterSensitiveLog: (obj: CreateServiceRequest) => any;
}
export declare enum ServiceState {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED"
}
export interface CreateServiceResponse {
    
    ServiceId?: string;
    
    Name?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    Description?: string;
    
    EnvironmentId?: string;
    
    ApplicationId?: string;
    
    VpcId?: string;
    
    EndpointType?: ServiceEndpointType | string;
    
    UrlEndpoint?: UrlEndpointInput;
    
    LambdaEndpoint?: LambdaEndpointInput;
    
    State?: ServiceState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace CreateServiceResponse {
    
    const filterSensitiveLog: (obj: CreateServiceResponse) => any;
}
export interface DeleteApplicationRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
}
export declare namespace DeleteApplicationRequest {
    
    const filterSensitiveLog: (obj: DeleteApplicationRequest) => any;
}
export interface DeleteApplicationResponse {
    
    Name?: string;
    
    Arn?: string;
    
    ApplicationId?: string;
    
    EnvironmentId?: string;
    
    State?: ApplicationState | string;
    
    LastUpdatedTime?: Date;
}
export declare namespace DeleteApplicationResponse {
    
    const filterSensitiveLog: (obj: DeleteApplicationResponse) => any;
}
export interface DeleteEnvironmentRequest {
    
    EnvironmentIdentifier: string | undefined;
}
export declare namespace DeleteEnvironmentRequest {
    
    const filterSensitiveLog: (obj: DeleteEnvironmentRequest) => any;
}
export interface DeleteEnvironmentResponse {
    
    Name?: string;
    
    Arn?: string;
    
    EnvironmentId?: string;
    
    State?: EnvironmentState | string;
    
    LastUpdatedTime?: Date;
}
export declare namespace DeleteEnvironmentResponse {
    
    const filterSensitiveLog: (obj: DeleteEnvironmentResponse) => any;
}
export interface DeleteResourcePolicyRequest {
    
    Identifier: string | undefined;
}
export declare namespace DeleteResourcePolicyRequest {
    
    const filterSensitiveLog: (obj: DeleteResourcePolicyRequest) => any;
}
export interface DeleteResourcePolicyResponse {
}
export declare namespace DeleteResourcePolicyResponse {
    
    const filterSensitiveLog: (obj: DeleteResourcePolicyResponse) => any;
}
export interface DeleteRouteRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    RouteIdentifier: string | undefined;
}
export declare namespace DeleteRouteRequest {
    
    const filterSensitiveLog: (obj: DeleteRouteRequest) => any;
}
export interface DeleteRouteResponse {
    
    RouteId?: string;
    
    Arn?: string;
    
    ServiceId?: string;
    
    ApplicationId?: string;
    
    State?: RouteState | string;
    
    LastUpdatedTime?: Date;
}
export declare namespace DeleteRouteResponse {
    
    const filterSensitiveLog: (obj: DeleteRouteResponse) => any;
}
export interface DeleteServiceRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    ServiceIdentifier: string | undefined;
}
export declare namespace DeleteServiceRequest {
    
    const filterSensitiveLog: (obj: DeleteServiceRequest) => any;
}
export interface DeleteServiceResponse {
    
    ServiceId?: string;
    
    Name?: string;
    
    Arn?: string;
    
    EnvironmentId?: string;
    
    ApplicationId?: string;
    
    State?: ServiceState | string;
    
    LastUpdatedTime?: Date;
}
export declare namespace DeleteServiceResponse {
    
    const filterSensitiveLog: (obj: DeleteServiceResponse) => any;
}

export interface EnvironmentSummary {
    
    Name?: string;
    
    Arn?: string;
    
    Description?: string;
    
    EnvironmentId?: string;
    
    NetworkFabricType?: NetworkFabricType | string;
    
    OwnerAccountId?: string;
    
    TransitGatewayId?: string;
    
    State?: EnvironmentState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace EnvironmentSummary {
    
    const filterSensitiveLog: (obj: EnvironmentSummary) => any;
}

export interface EnvironmentVpc {
    
    EnvironmentId?: string;
    
    VpcId?: string;
    
    AccountId?: string;
    
    CidrBlocks?: string[];
    
    VpcName?: string;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace EnvironmentVpc {
    
    const filterSensitiveLog: (obj: EnvironmentVpc) => any;
}
export interface GetApplicationRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
}
export declare namespace GetApplicationRequest {
    
    const filterSensitiveLog: (obj: GetApplicationRequest) => any;
}
export interface GetApplicationResponse {
    
    Name?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    ApplicationId?: string;
    
    EnvironmentId?: string;
    
    VpcId?: string;
    
    ProxyType?: ProxyType | string;
    
    ApiGatewayProxy?: ApiGatewayProxyConfig;
    
    State?: ApplicationState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace GetApplicationResponse {
    
    const filterSensitiveLog: (obj: GetApplicationResponse) => any;
}
export interface GetEnvironmentRequest {
    
    EnvironmentIdentifier: string | undefined;
}
export declare namespace GetEnvironmentRequest {
    
    const filterSensitiveLog: (obj: GetEnvironmentRequest) => any;
}
export interface GetEnvironmentResponse {
    
    Name?: string;
    
    Arn?: string;
    
    Description?: string;
    
    EnvironmentId?: string;
    
    NetworkFabricType?: NetworkFabricType | string;
    
    OwnerAccountId?: string;
    
    TransitGatewayId?: string;
    
    State?: EnvironmentState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace GetEnvironmentResponse {
    
    const filterSensitiveLog: (obj: GetEnvironmentResponse) => any;
}
export interface GetResourcePolicyRequest {
    
    Identifier: string | undefined;
}
export declare namespace GetResourcePolicyRequest {
    
    const filterSensitiveLog: (obj: GetResourcePolicyRequest) => any;
}
export interface GetResourcePolicyResponse {
    
    Policy?: string;
}
export declare namespace GetResourcePolicyResponse {
    
    const filterSensitiveLog: (obj: GetResourcePolicyResponse) => any;
}
export interface GetRouteRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    RouteIdentifier: string | undefined;
}
export declare namespace GetRouteRequest {
    
    const filterSensitiveLog: (obj: GetRouteRequest) => any;
}
export interface GetRouteResponse {
    
    RouteId?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    RouteType?: RouteType | string;
    
    ServiceId?: string;
    
    ApplicationId?: string;
    
    EnvironmentId?: string;
    
    SourcePath?: string;
    
    Methods?: (HttpMethod | string)[];
    
    IncludeChildPaths?: boolean;
    
    PathResourceToId?: {
        [key: string]: string;
    };
    
    State?: RouteState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace GetRouteResponse {
    
    const filterSensitiveLog: (obj: GetRouteResponse) => any;
}
export interface GetServiceRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    ServiceIdentifier: string | undefined;
}
export declare namespace GetServiceRequest {
    
    const filterSensitiveLog: (obj: GetServiceRequest) => any;
}

export interface LambdaEndpointConfig {
    
    Arn?: string;
}
export declare namespace LambdaEndpointConfig {
    
    const filterSensitiveLog: (obj: LambdaEndpointConfig) => any;
}

export interface UrlEndpointConfig {
    
    Url?: string;
    
    HealthUrl?: string;
}
export declare namespace UrlEndpointConfig {
    
    const filterSensitiveLog: (obj: UrlEndpointConfig) => any;
}
export interface GetServiceResponse {
    
    ServiceId?: string;
    
    Name?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    Description?: string;
    
    EnvironmentId?: string;
    
    ApplicationId?: string;
    
    VpcId?: string;
    
    EndpointType?: ServiceEndpointType | string;
    
    UrlEndpoint?: UrlEndpointConfig;
    
    LambdaEndpoint?: LambdaEndpointConfig;
    
    State?: ServiceState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace GetServiceResponse {
    
    const filterSensitiveLog: (obj: GetServiceResponse) => any;
}

export declare class InvalidResourcePolicyException extends __BaseException {
    readonly name: "InvalidResourcePolicyException";
    readonly $fault: "client";
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<InvalidResourcePolicyException, __BaseException>);
}

export interface LambdaEndpointSummary {
    
    Arn?: string;
}
export declare namespace LambdaEndpointSummary {
    
    const filterSensitiveLog: (obj: LambdaEndpointSummary) => any;
}
export interface ListApplicationsRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListApplicationsRequest {
    
    const filterSensitiveLog: (obj: ListApplicationsRequest) => any;
}
export interface ListApplicationsResponse {
    
    ApplicationSummaryList?: ApplicationSummary[];
    
    NextToken?: string;
}
export declare namespace ListApplicationsResponse {
    
    const filterSensitiveLog: (obj: ListApplicationsResponse) => any;
}
export interface ListEnvironmentsRequest {
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListEnvironmentsRequest {
    
    const filterSensitiveLog: (obj: ListEnvironmentsRequest) => any;
}
export interface ListEnvironmentsResponse {
    
    EnvironmentSummaryList?: EnvironmentSummary[];
    
    NextToken?: string;
}
export declare namespace ListEnvironmentsResponse {
    
    const filterSensitiveLog: (obj: ListEnvironmentsResponse) => any;
}
export interface ListEnvironmentVpcsRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListEnvironmentVpcsRequest {
    
    const filterSensitiveLog: (obj: ListEnvironmentVpcsRequest) => any;
}
export interface ListEnvironmentVpcsResponse {
    
    EnvironmentVpcList?: EnvironmentVpc[];
    
    NextToken?: string;
}
export declare namespace ListEnvironmentVpcsResponse {
    
    const filterSensitiveLog: (obj: ListEnvironmentVpcsResponse) => any;
}
export interface ListRoutesRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListRoutesRequest {
    
    const filterSensitiveLog: (obj: ListRoutesRequest) => any;
}

export interface RouteSummary {
    
    RouteId?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    RouteType?: RouteType | string;
    
    ServiceId?: string;
    
    ApplicationId?: string;
    
    EnvironmentId?: string;
    
    SourcePath?: string;
    
    Methods?: (HttpMethod | string)[];
    
    IncludeChildPaths?: boolean;
    
    PathResourceToId?: {
        [key: string]: string;
    };
    
    State?: RouteState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace RouteSummary {
    
    const filterSensitiveLog: (obj: RouteSummary) => any;
}
export interface ListRoutesResponse {
    
    RouteSummaryList?: RouteSummary[];
    
    NextToken?: string;
}
export declare namespace ListRoutesResponse {
    
    const filterSensitiveLog: (obj: ListRoutesResponse) => any;
}
export interface ListServicesRequest {
    
    EnvironmentIdentifier: string | undefined;
    
    ApplicationIdentifier: string | undefined;
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListServicesRequest {
    
    const filterSensitiveLog: (obj: ListServicesRequest) => any;
}

export interface UrlEndpointSummary {
    
    Url?: string;
    
    HealthUrl?: string;
}
export declare namespace UrlEndpointSummary {
    
    const filterSensitiveLog: (obj: UrlEndpointSummary) => any;
}

export interface ServiceSummary {
    
    ServiceId?: string;
    
    Name?: string;
    
    Arn?: string;
    
    OwnerAccountId?: string;
    
    CreatedByAccountId?: string;
    
    Description?: string;
    
    EnvironmentId?: string;
    
    ApplicationId?: string;
    
    VpcId?: string;
    
    EndpointType?: ServiceEndpointType | string;
    
    UrlEndpoint?: UrlEndpointSummary;
    
    LambdaEndpoint?: LambdaEndpointSummary;
    
    State?: ServiceState | string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Error?: ErrorResponse;
    
    LastUpdatedTime?: Date;
    
    CreatedTime?: Date;
}
export declare namespace ServiceSummary {
    
    const filterSensitiveLog: (obj: ServiceSummary) => any;
}
export interface ListServicesResponse {
    
    ServiceSummaryList?: ServiceSummary[];
    
    NextToken?: string;
}
export declare namespace ListServicesResponse {
    
    const filterSensitiveLog: (obj: ListServicesResponse) => any;
}
export interface ListTagsForResourceRequest {
    
    ResourceArn: string | undefined;
}
export declare namespace ListTagsForResourceRequest {
    
    const filterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
}
export interface ListTagsForResourceResponse {
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace ListTagsForResourceResponse {
    
    const filterSensitiveLog: (obj: ListTagsForResourceResponse) => any;
}
export interface PutResourcePolicyRequest {
    
    ResourceArn: string | undefined;
    
    Policy: string | undefined;
}
export declare namespace PutResourcePolicyRequest {
    
    const filterSensitiveLog: (obj: PutResourcePolicyRequest) => any;
}
export interface PutResourcePolicyResponse {
}
export declare namespace PutResourcePolicyResponse {
    
    const filterSensitiveLog: (obj: PutResourcePolicyResponse) => any;
}
export interface TagResourceRequest {
    
    ResourceArn: string | undefined;
    
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagResourceRequest {
    
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResponse {
}
export declare namespace TagResourceResponse {
    
    const filterSensitiveLog: (obj: TagResourceResponse) => any;
}
export interface UntagResourceRequest {
    
    ResourceArn: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResponse {
}
export declare namespace UntagResourceResponse {
    
    const filterSensitiveLog: (obj: UntagResourceResponse) => any;
}
